Description: <short summary of the patch>
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 axiom (20170501-4) unstable; urgency=high
 .
   * drop -perm constraint on axiom bin/* installs,
   * Bug fix: "/usr/lib/axiom-20170401/bin missing when package is
     rebuilt", thanks to Juhani Numminen (Closes: #919649).
   * UseRawInputEncoding patch for newest TeX UTF-8 standards
Author: Camm Maguire <camm@debian.org>
Bug-Debian: https://bugs.debian.org/919649

---
The information above should follow the Patch Tagging Guidelines, please
checkout http://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: <vendor|upstream|other>, <url of original patch>
Bug: <url in upstream bugtracker>
Bug-Debian: https://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: <no|not-needed|url proving that it has been forwarded>
Reviewed-By: <name and email of someone who approved the patch>
Last-Update: 2020-08-18

--- axiom-20170501.orig/books/bookvol7.pamphlet
+++ axiom-20170501/books/bookvol7.pamphlet
@@ -8940,7 +8940,7 @@ int gXScreenNumber;
 Sock *sessionServer = NULL;
 Sock *spadSocket = NULL;
 int still_reading; 
-int str_len;
+extern int str_len;
 
 \end{chunk}
 \section{The Shared Code}
